@@ -1,23 +1,30 @@
-import os
-import unittest
-from unittest import mock
+"""
+Tests for the built-in form classes.
+
+"""
+
+# SPDX-License-Identifier: BSD-3-Clause
 
 from django.conf import settings
 from django.core import mail
 from django.test import RequestFactory, TestCase
 
-from django_contact_form.forms import AkismetContactForm, ContactForm
+from django_contact_form.forms import ContactForm
 
 
 class ContactFormTests(TestCase):
     """
-    Tests the base ContactForm.
+    Tests for the base ContactForm.
 
     """
 
     valid_data = {"name": "Test", "email": "test@example.com", "body": "Test message"}
 
     def request(self):
+        """
+        Construct and return an HttpRequest object for test use.
+
+        """
         return RequestFactory().request()
 
     def test_request_required(self):
@@ -43,15 +50,15 @@ class ContactFormTests(TestCase):
 
         """
         form = ContactForm(request=self.request(), data=self.valid_data)
-        self.assertTrue(form.is_valid())
+        assert form.is_valid()
 
         form.save()
-        self.assertEqual(1, len(mail.outbox))
+        assert 1 == len(mail.outbox)
 
         message = mail.outbox[0]
-        self.assertTrue(self.valid_data["body"] in message.body)
-        self.assertEqual(settings.DEFAULT_FROM_EMAIL, message.from_email)
-        self.assertEqual(form.recipient_list, message.recipients())
+        assert self.valid_data["body"] in message.body
+        assert settings.DEFAULT_FROM_EMAIL == message.from_email
+        assert form.recipient_list == message.recipients()
 
     def test_no_sites(self):
         """
@@ -61,10 +68,10 @@ class ContactFormTests(TestCase):
         """
         with self.modify_settings(INSTALLED_APPS={"remove": ["django.contrib.sites"]}):
             form = ContactForm(request=self.request(), data=self.valid_data)
-            self.assertTrue(form.is_valid())
+            assert form.is_valid()
 
             form.save()
-            self.assertEqual(1, len(mail.outbox))
+            assert 1 == len(mail.outbox)
 
     def test_recipient_list(self):
         """
@@ -76,13 +83,13 @@ class ContactFormTests(TestCase):
         form = ContactForm(
             request=self.request(), data=self.valid_data, recipient_list=recipient_list
         )
-        self.assertTrue(form.is_valid())
+        assert form.is_valid()
 
         form.save()
-        self.assertEqual(1, len(mail.outbox))
+        assert 1 == len(mail.outbox)
 
         message = mail.outbox[0]
-        self.assertEqual(recipient_list, message.recipients())
+        assert recipient_list == message.recipients()
 
     def test_callable_template_name(self):
         """
@@ -92,17 +99,27 @@ class ContactFormTests(TestCase):
         """
 
         class CallableTemplateName(ContactForm):
+            """
+            Form with a template_name() method instead of a template_name attribute.
+
+            """
+
+            # pylint: disable=invalid-overridden-method
             def template_name(self):
+                """
+                Return the template name as a method rather than an attribute.
+
+                """
                 return "django_contact_form/test_callable_template_name.html"
 
         form = CallableTemplateName(request=self.request(), data=self.valid_data)
-        self.assertTrue(form.is_valid())
+        assert form.is_valid()
 
         form.save()
-        self.assertEqual(1, len(mail.outbox))
+        assert 1 == len(mail.outbox)
 
         message = mail.outbox[0]
-        self.assertTrue("Callable template_name used." in message.body)
+        assert "Callable template_name used." in message.body
 
     def test_callable_message_parts(self):
         """
@@ -118,78 +135,40 @@ class ContactFormTests(TestCase):
         }
 
         class CallableMessageParts(ContactForm):
+            """
+            Form with the message parts as methods rather than attributes.
+
+            """
+
             def from_email(self):
+                """
+                Method returning the from_email.
+
+                """
                 return overridden_data["from_email"]
 
             def message(self):
+                """
+                Method returning the message.
+
+                """
                 return overridden_data["message"]
 
-            def recipient_list(self):
+            def recipient_list(self):  # pylint: disable=method-hidden
+                """
+                Method returning the recipient_list.
+
+                """
                 return overridden_data["recipient_list"]
 
             def subject(self):
+                """
+                Method returning the subject.
+
+                """
                 return overridden_data["subject"]
 
         form = CallableMessageParts(request=self.request(), data=self.valid_data)
-        self.assertTrue(form.is_valid())
+        assert form.is_valid()
 
-        self.assertEqual(overridden_data, form.get_message_dict())
-
-
-@unittest.skipUnless(
-    getattr(settings, "AKISMET_API_KEY", os.getenv("PYTHON_AKISMET_API_KEY"))
-    is not None,
-    "AkismetContactForm requires Akismet configuration",
-)
-class AkismetContactFormTests(TestCase):
-    """
-    Tests the Akismet contact form.
-
-    """
-
-    def request(self):
-        return RequestFactory().request()
-
-    def test_akismet_form_spam(self):
-        """
-        The Akismet contact form correctly rejects spam.
-
-        """
-        data = {
-            "name": "viagra-test-123",
-            "email": "email@example.com",
-            "body": "This is spam.",
-        }
-        with mock.patch("akismet.Akismet", autospec=True) as akismet_mock:
-            instance = akismet_mock.return_value
-            instance.verify_key.return_value = True
-            instance.comment_check.return_value = True
-            form = AkismetContactForm(request=self.request(), data=data)
-            self.assertFalse(form.is_valid())
-            self.assertTrue(str(form.SPAM_MESSAGE) in form.errors["body"])
-
-    def test_akismet_form_ham(self):
-        """
-        The Akismet contact form correctly accepts non-spam.
-
-        """
-        data = {"name": "Test", "email": "email@example.com", "body": "Test message."}
-        with mock.patch("akismet.Akismet", autospec=True) as akismet_mock:
-            instance = akismet_mock.return_value
-            instance.verify_key.return_value = True
-            instance.comment_check.return_value = False
-            form = AkismetContactForm(request=self.request(), data=data)
-            self.assertTrue(form.is_valid())
-
-    def test_akismet_form_no_body(self):
-        """
-        The Akismet contact form correctly skips validation when no email
-        body is provided.
-
-        """
-        data = {"name": "Test", "email": "email@example.com"}
-        with mock.patch("akismet.Akismet", autospec=True) as akismet_mock:
-            form = AkismetContactForm(request=self.request(), data=data)
-            self.assertFalse(form.is_valid())
-            akismet_mock.assert_not_called()
-            self.assertFalse(form.is_valid())
+        assert overridden_data == form.get_message_dict()
