@@ -3,10 +3,11 @@ URLConf for testing django-contact-form.
 
 """
 
+# SPDX-License-Identifier: BSD-3-Clause
+
 from django.urls import path
 from django.views.generic import TemplateView
 
-from django_contact_form.forms import AkismetContactForm
 from django_contact_form.views import ContactFormView
 
 urlpatterns = [
@@ -23,9 +24,4 @@ urlpatterns = [
         ContactFormView.as_view(recipient_list=["recipient_list@example.com"]),
         name="test_recipient_list",
     ),
-    path(
-        "test_akismet_form/",
-        ContactFormView.as_view(form_class=AkismetContactForm),
-        name="test_akismet_form",
-    ),
 ]
